TemperatureAndRelativeHumidity

Struct TemperatureAndRelativeHumidity 

pub struct TemperatureAndRelativeHumidity<T: Temperature> {
    pub temperature: T,
    pub relative_humidity: RelativeHumidity,
}
The combination of the temperature and the relative humidity.

Fields

temperature: T

The temperature (either in °C or °F).

relative_humidity: RelativeHumidity

The relative humidity (in %).

Implementations

Source

impl<T: Temperature> TemperatureAndRelativeHumidity<T>

pub fn absolute_humidity(&self) -> AbsoluteHumidity

Computes the absolute humidity value (in g/m³). The absolute humidity is defined by the mass of water vapor per humid air volume.

pub fn dew_point(&self) -> T

Computes the dew point temperature. The dew point temperature is defined as the temperature to which the quantity of air must be cooled down such that, at constant pressure, condensation occurs.

pub fn heat_index(&self) -> HeatIndex<T>

Computes the heat index.

See HeatIndex.