pub struct HeatIndex<T: Temperature>(/* private fields */);Expand description
The heat index.
The heat index indicates how the human body feels temperature. If relative humidity is low human body cools itself by perspiration, dissipating heat from the body. At higher relative humidity the evaporation rate from the human skin is lower. In that case, the body cannot dissipate heat as easily as it is the case in dry air. The heat index is based on subjective measurements and is only meaningful above 25°C and 40% RH.
Implementations