pub struct TemperatureAndRelativeHumidity<T: Temperature> {
pub temperature: T,
pub relative_humidity: RelativeHumidity,
}Expand description
The combination of the temperature and the relative humidity.
Fields
temperature: TThe temperature (either in °C or °F).
relative_humidity: RelativeHumidityThe relative humidity (in %).
Implementations
Sourceimpl<T: Temperature> TemperatureAndRelativeHumidity<T>
impl<T: Temperature> TemperatureAndRelativeHumidity<T>
Sourcepub fn absolute_humidity(&self) -> AbsoluteHumidity
pub fn absolute_humidity(&self) -> AbsoluteHumidity
Computes the absolute humidity value (in g/m³). The absolute humidity is defined by the mass of water vapor per humid air volume.
Sourcepub fn dew_point(&self) -> T
pub fn dew_point(&self) -> T
Computes the dew point temperature. The dew point temperature is defined as the temperature to which the quantity of air must be cooled down such that, at constant pressure, condensation occurs.
Sourcepub fn heat_index(&self) -> HeatIndex<T>
pub fn heat_index(&self) -> HeatIndex<T>
Computes the heat index.
See HeatIndex.